﻿using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using System.Windows.Markup;

namespace Hardcodet.Wpf.Converters
{
  /// <summary>
  /// Converts a boolean value into a <see cref="Visibility"/>
  /// flag, optionally inverted by setting the parameter
  /// to an arbitrary value. If no parameter is being set,
  /// a boolean value of True is being converted to
  /// <see cref="Visibility.Visible"/>, while a false value
  /// will result in <see cref="Visibility.Collapsed"/>.
  /// </summary>
  [ValueConversion(typeof (bool), typeof (Visibility))]
  public class BoolToVisibilityConverter : ConverterExtension
  {
    /// <summary>
    /// Collapses an item if the submitted value is not true.
    /// </summary>
    public override object Convert(object value, Type targetType, object parameter, CultureInfo culture)
    {
      bool status = (bool?) value ?? false;

      //invert the parameter if it's anything but null
      if (parameter != null) status = !status;
      
      return status ? Visibility.Visible : Visibility.Collapsed;
    }


    public override object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
    {
      Visibility visiblity = (Visibility) value;
      return visiblity == Visibility.Visible;
    }
  }
}