﻿using System;
using System.ComponentModel;
using System.Globalization;
using System.Reflection;
using System.Windows.Data;


namespace Hardcodet.Wpf.Converters
{
  ///<summary>
  /// Converts an enum value into a description base on a
  /// <see cref="DescriptionAttribute"/> that was assigned to
  /// the submitted enum value.
  ///</summary>
  [ValueConversion(typeof(Enum), typeof(string))]
  public class EnumToDescriptionConverter : ConverterExtension
  {

    public override object Convert(object value, Type targetType, object parameter, CultureInfo culture)
    {
      Enum en = value as Enum;
      if (en == null) return null;

      // Get the Description attribute value for the enum value
      FieldInfo fi = value.GetType().GetField(value.ToString());

      var attributes = (DescriptionAttribute[])fi.GetCustomAttributes(
              typeof(DescriptionAttribute), false);

      if (attributes.Length > 0) return attributes[0].Description;
      return en.ToString();
    }

  }
}