﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Data;
using System.Windows.Media;

namespace Hardcodet.Wpf.Util
{
  /// <summary>
  /// Provides UI-related helper methods.
  /// </summary>
  public static class UIHelper
  {
    #region update binding sources

    /// <summary>
    /// Recursively processes a given dependency object and all its
    /// children, and updates sources of all objects that use a
    /// binding expression on a given property.
    /// </summary>
    /// <param name="obj">The dependency object that marks a starting
    /// point. This could be a dialog window or a panel control that
    /// hosts bound controls.</param>
    /// <param name="properties">The properties to be updated if
    /// <paramref name="obj"/> or one of its childs provide it along
    /// with a binding expression.</param>
    public static void UpdateBindingSources(DependencyObject obj,
                                            params DependencyProperty[] properties)
    {
      foreach (DependencyProperty depProperty in properties)
      {
        //check whether the submitted object provides a bound property
        //that matches the property parameters
        BindingExpression be = BindingOperations.GetBindingExpression(obj, depProperty);
        if (be != null) be.UpdateSource();
      }

      int count = VisualTreeHelper.GetChildrenCount(obj);
      for (int i = 0; i < count; i++)
      {
        //process child items recursively
        DependencyObject childObject = VisualTreeHelper.GetChild(obj, i);
        UpdateBindingSources(childObject, properties);
      }
    }

    #endregion
  }
}
